@@ -11,6 +11,7 @@ import fnmatch
 import functools
 import json
 import os
+import pathlib
 import queue
 import re
 import shutil
@@ -83,6 +84,7 @@ if t.TYPE_CHECKING:
     FilesManifestType = t.Dict[t.Literal['files', 'format'], t.Union[t.List[FileManifestEntryType], int]]
 
 import ansible.constants as C
+from ansible.compat.importlib_resources import files
 from ansible.errors import AnsibleError
 from ansible.galaxy.api import GalaxyAPI
 from ansible.galaxy.collection.concrete_artifact_manager import (
@@ -122,7 +124,6 @@ from ansible.galaxy.dependency_resolution.dataclasses import (
 )
 from ansible.galaxy.dependency_resolution.versioning import meets_requirements
 from ansible.plugins.loader import get_all_plugin_loaders
-from ansible.module_utils.six import raise_from
 from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.common.collections import is_sequence
 from ansible.module_utils.common.yaml import yaml_dump
@@ -282,11 +283,8 @@ def verify_local_collection(local_collection, remote_collection, artifacts_manag
         manifest_hash = get_hash_from_validation_source(MANIFEST_FILENAME)
     else:
         # fetch remote
-        b_temp_tar_path = (  # NOTE: AnsibleError is raised on URLError
-            artifacts_manager.get_artifact_path
-            if remote_collection.is_concrete_artifact
-            else artifacts_manager.get_galaxy_artifact_path
-        )(remote_collection)
+        # NOTE: AnsibleError is raised on URLError
+        b_temp_tar_path = artifacts_manager.get_artifact_path_from_unknown(remote_collection)
 
         display.vvv(
             u"Remote collection cached as '{path!s}'".format(path=to_text(b_temp_tar_path))
@@ -470,7 +468,7 @@ def build_collection(u_collection_path, u_output_path, force):
     try:
         collection_meta = _get_meta_from_src_dir(b_collection_path)
     except LookupError as lookup_err:
-        raise_from(AnsibleError(to_native(lookup_err)), lookup_err)
+        raise AnsibleError(to_native(lookup_err)) from lookup_err
 
     collection_manifest = _build_manifest(**collection_meta)
     file_manifest = _build_files_manifest(
@@ -479,6 +477,7 @@ def build_collection(u_collection_path, u_output_path, force):
         collection_meta['name'],  # type: ignore[arg-type]
         collection_meta['build_ignore'],  # type: ignore[arg-type]
         collection_meta['manifest'],  # type: ignore[arg-type]
+        collection_meta['license_file'],  # type: ignore[arg-type]
     )
 
     artifact_tarball_file_name = '{ns!s}-{name!s}-{ver!s}.tar.gz'.format(
@@ -555,11 +554,7 @@ def download_collections(
                 format(coll=to_text(concrete_coll_pin), path=to_text(b_output_path)),
             )
 
-            b_src_path = (
-                artifacts_manager.get_artifact_path
-                if concrete_coll_pin.is_concrete_artifact
-                else artifacts_manager.get_galaxy_artifact_path
-            )(concrete_coll_pin)
+            b_src_path = artifacts_manager.get_artifact_path_from_unknown(concrete_coll_pin)
 
             b_dest_path = os.path.join(
                 b_output_path,
@@ -679,7 +674,7 @@ def install_collections(
     unsatisfied_requirements = set(
         chain.from_iterable(
             (
-                Requirement.from_dir_path(sub_coll, artifacts_manager)
+                Requirement.from_dir_path(to_bytes(sub_coll), artifacts_manager)
                 for sub_coll in (
                     artifacts_manager.
                     get_direct_collection_dependencies(install_req).
@@ -1065,8 +1060,9 @@ def _make_entry(name, ftype, chksum_type='sha256', chksum=None):
     }
 
 
-def _build_files_manifest(b_collection_path, namespace, name, ignore_patterns, manifest_control):
-    # type: (bytes, str, str, list[str], dict[str, t.Any]) -> FilesManifestType
+def _build_files_manifest(b_collection_path, namespace, name, ignore_patterns,
+                          manifest_control, license_file):
+    # type: (bytes, str, str, list[str], dict[str, t.Any], t.Optional[str]) -> FilesManifestType
     if ignore_patterns and manifest_control is not Sentinel:
         raise AnsibleError('"build_ignore" and "manifest" are mutually exclusive')
 
@@ -1076,14 +1072,15 @@ def _build_files_manifest(b_collection_path, namespace, name, ignore_patterns, m
             namespace,
             name,
             manifest_control,
+            license_file,
         )
 
     return _build_files_manifest_walk(b_collection_path, namespace, name, ignore_patterns)
 
 
-def _build_files_manifest_distlib(b_collection_path, namespace, name, manifest_control):
-    # type: (bytes, str, str, dict[str, t.Any]) -> FilesManifestType
-
+def _build_files_manifest_distlib(b_collection_path, namespace, name, manifest_control,
+                                  license_file):
+    # type: (bytes, str, str, dict[str, t.Any], t.Optional[str]) -> FilesManifestType
     if not HAS_DISTLIB:
         raise AnsibleError('Use of "manifest" requires the python "distlib" library')
 
@@ -1116,15 +1113,20 @@ def _build_files_manifest_distlib(b_collection_path, namespace, name, manifest_c
     else:
         directives.extend([
             'include meta/*.yml',
-            'include *.txt *.md *.rst COPYING LICENSE',
+            'include *.txt *.md *.rst *.license COPYING LICENSE',
+            'recursive-include .reuse **',
+            'recursive-include LICENSES **',
             'recursive-include tests **',
-            'recursive-include docs **.rst **.yml **.yaml **.json **.j2 **.txt',
-            'recursive-include roles **.yml **.yaml **.json **.j2',
-            'recursive-include playbooks **.yml **.yaml **.json',
-            'recursive-include changelogs **.yml **.yaml',
-            'recursive-include plugins */**.py',
+            'recursive-include docs **.rst **.yml **.yaml **.json **.j2 **.txt **.license',
+            'recursive-include roles **.yml **.yaml **.json **.j2 **.license',
+            'recursive-include playbooks **.yml **.yaml **.json **.license',
+            'recursive-include changelogs **.yml **.yaml **.license',
+            'recursive-include plugins */**.py */**.license',
         ])
 
+        if license_file:
+            directives.append(f'include {license_file}')
+
         plugins = set(l.package.split('.')[-1] for d, l in get_all_plugin_loaders())
         for plugin in sorted(plugins):
             if plugin in ('modules', 'module_utils'):
@@ -1135,8 +1137,8 @@ def _build_files_manifest_distlib(b_collection_path, namespace, name, manifest_c
                 )
 
         directives.extend([
-            'recursive-include plugins/modules **.ps1 **.yml **.yaml',
-            'recursive-include plugins/module_utils **.ps1 **.psm1 **.cs',
+            'recursive-include plugins/modules **.ps1 **.yml **.yaml **.license',
+            'recursive-include plugins/module_utils **.ps1 **.psm1 **.cs **.license',
         ])
 
         directives.extend(control.directives)
@@ -1144,7 +1146,7 @@ def _build_files_manifest_distlib(b_collection_path, namespace, name, manifest_c
         directives.extend([
             f'exclude galaxy.yml galaxy.yaml MANIFEST.json FILES.json {namespace}-{name}-*.tar.gz',
             'recursive-exclude tests/output **',
-            'global-exclude /.* /__pycache__',
+            'global-exclude /.* /__pycache__ *.pyc *.pyo *.bak *~ *.swp',
         ])
 
     display.vvv('Manifest Directives:')
@@ -1375,51 +1377,97 @@ def _build_collection_dir(b_collection_path, b_collection_output, collection_man
         src_file = os.path.join(b_collection_path, to_bytes(file_info['name'], errors='surrogate_or_strict'))
         dest_file = os.path.join(b_collection_output, to_bytes(file_info['name'], errors='surrogate_or_strict'))
 
-        existing_is_exec = os.stat(src_file).st_mode & stat.S_IXUSR
+        existing_is_exec = os.stat(src_file, follow_symlinks=False).st_mode & stat.S_IXUSR
         mode = 0o0755 if existing_is_exec else 0o0644
 
-        if os.path.isdir(src_file):
+        # ensure symlinks to dirs are not translated to empty dirs
+        if os.path.isdir(src_file) and not os.path.islink(src_file):
             mode = 0o0755
             base_directories.append(src_file)
             os.mkdir(dest_file, mode)
         else:
-            shutil.copyfile(src_file, dest_file)
+            # do not follow symlinks to ensure the original link is used
+            shutil.copyfile(src_file, dest_file, follow_symlinks=False)
+
+        # avoid setting specific permission on symlinks since it does not
+        # support avoid following symlinks and will thrown an exception if the
+        # symlink target does not exist
+        if not os.path.islink(dest_file):
+            os.chmod(dest_file, mode)
 
-        os.chmod(dest_file, mode)
     collection_output = to_text(b_collection_output)
     return collection_output
 
 
-def find_existing_collections(path, artifacts_manager):
+def _normalize_collection_path(path):
+    str_path = path.as_posix() if isinstance(path, pathlib.Path) else path
+    return pathlib.Path(
+        # This is annoying, but GalaxyCLI._resolve_path did it
+        os.path.expandvars(str_path)
+    ).expanduser().absolute()
+
+
+def find_existing_collections(path_filter, artifacts_manager, namespace_filter=None, collection_filter=None, dedupe=True):
     """Locate all collections under a given path.
 
     :param path: Collection dirs layout search path.
     :param artifacts_manager: Artifacts manager.
     """
-    b_path = to_bytes(path, errors='surrogate_or_strict')
+    if files is None:
+        raise AnsibleError('importlib_resources is not installed and is required')
 
-    # FIXME: consider using `glob.glob()` to simplify looping
-    for b_namespace in os.listdir(b_path):
-        b_namespace_path = os.path.join(b_path, b_namespace)
-        if os.path.isfile(b_namespace_path):
+    if path_filter and not is_sequence(path_filter):
+        path_filter = [path_filter]
+
+    paths = set()
+    for path in files('ansible_collections').glob('*/*/'):
+        path = _normalize_collection_path(path)
+        if not path.is_dir():
+            continue
+        if path_filter:
+            for pf in path_filter:
+                try:
+                    path.relative_to(_normalize_collection_path(pf))
+                except ValueError:
+                    continue
+                break
+            else:
+                continue
+        paths.add(path)
+
+    seen = set()
+    for path in paths:
+        namespace = path.parent.name
+        name = path.name
+        if namespace_filter and namespace != namespace_filter:
+            continue
+        if collection_filter and name != collection_filter:
             continue
 
-        # FIXME: consider feeding b_namespace_path to Candidate.from_dir_path to get subdirs automatically
-        for b_collection in os.listdir(b_namespace_path):
-            b_collection_path = os.path.join(b_namespace_path, b_collection)
-            if not os.path.isdir(b_collection_path):
-                continue
-
+        if dedupe:
             try:
-                req = Candidate.from_dir_path_as_unknown(b_collection_path, artifacts_manager)
-            except ValueError as val_err:
-                raise_from(AnsibleError(val_err), val_err)
+                collection_path = files(f'ansible_collections.{namespace}.{name}')
+            except ImportError:
+                continue
+            if collection_path in seen:
+                continue
+            seen.add(collection_path)
+        else:
+            collection_path = path
 
-            display.vvv(
-                u"Found installed collection {coll!s} at '{path!s}'".
-                format(coll=to_text(req), path=to_text(req.src))
-            )
-            yield req
+        b_collection_path = to_bytes(collection_path.as_posix())
+
+        try:
+            req = Candidate.from_dir_path_as_unknown(b_collection_path, artifacts_manager)
+        except ValueError as val_err:
+            display.warning(f'{val_err}')
+            continue
+
+        display.vvv(
+            u"Found installed collection {coll!s} at '{path!s}'".
+            format(coll=to_text(req), path=to_text(req.src))
+        )
+        yield req
 
 
 def install(collection, path, artifacts_manager):  # FIXME: mv to dataclasses?
@@ -1430,10 +1478,7 @@ def install(collection, path, artifacts_manager):  # FIXME: mv to dataclasses?
     :param path: Collection dirs layout path.
     :param artifacts_manager: Artifacts manager.
     """
-    b_artifact_path = (
-        artifacts_manager.get_artifact_path if collection.is_concrete_artifact
-        else artifacts_manager.get_galaxy_artifact_path
-    )(collection)
+    b_artifact_path = artifacts_manager.get_artifact_path_from_unknown(collection)
 
     collection_path = os.path.join(path, collection.namespace, collection.name)
     b_collection_path = to_bytes(collection_path, errors='surrogate_or_strict')
@@ -1516,13 +1561,6 @@ def install_artifact(b_coll_targz_path, b_collection_path, b_temp_path, signatur
     """
     try:
         with tarfile.open(b_coll_targz_path, mode='r') as collection_tar:
-            # Remove this once py3.11 is our controller minimum
-            # Workaround for https://bugs.python.org/issue47231
-            # See _extract_tar_dir
-            collection_tar._ansible_normalized_cache = {
-                m.name.removesuffix(os.path.sep): m for m in collection_tar.getmembers()
-            }  # deprecated: description='TarFile member index' core_version='2.18' python_version='3.11'
-
             # Verify the signature on the MANIFEST.json before extracting anything else
             _extract_tar_file(collection_tar, MANIFEST_FILENAME, b_collection_path, b_temp_path)
 
@@ -1587,6 +1625,7 @@ def install_src(collection, b_collection_path, b_collection_output_path, artifac
         collection_meta['namespace'], collection_meta['name'],
         collection_meta['build_ignore'],
         collection_meta['manifest'],
+        collection_meta['license_file'],
     )
 
     collection_output_path = _build_collection_dir(
@@ -1602,12 +1641,22 @@ def install_src(collection, b_collection_path, b_collection_output_path, artifac
 
 def _extract_tar_dir(tar, dirname, b_dest):
     """ Extracts a directory from a collection tar. """
-    dirname = to_native(dirname, errors='surrogate_or_strict').removesuffix(os.path.sep)
+    member_names = [to_native(dirname, errors='surrogate_or_strict')]
 
-    try:
-        tar_member = tar._ansible_normalized_cache[dirname]
-    except KeyError:
-        raise AnsibleError("Unable to extract '%s' from collection" % dirname)
+    # Create list of members with and without trailing separator
+    if not member_names[-1].endswith(os.path.sep):
+        member_names.append(member_names[-1] + os.path.sep)
+
+    # Try all of the member names and stop on the first one that are able to successfully get
+    for member in member_names:
+        try:
+            tar_member = tar.getmember(member)
+        except KeyError:
+            continue
+        break
+    else:
+        # If we still can't find the member, raise a nice error.
+        raise AnsibleError("Unable to extract '%s' from collection" % to_native(member, errors='surrogate_or_strict'))
 
     b_dir_path = os.path.join(b_dest, to_bytes(dirname, errors='surrogate_or_strict'))
 
@@ -1798,10 +1847,7 @@ def _resolve_depenency_map(
             ),
             conflict_causes,
         ))
-        raise raise_from(  # NOTE: Leading "raise" is a hack for mypy bug #9717
-            AnsibleError('\n'.join(error_msg_lines)),
-            dep_exc,
-        )
+        raise AnsibleError('\n'.join(error_msg_lines)) from dep_exc
     except CollectionDependencyInconsistentCandidate as dep_exc:
         parents = [
             "%s.%s:%s" % (p.namespace, p.name, p.ver)
@@ -1828,9 +1874,6 @@ def _resolve_depenency_map(
                 '* {req.fqcn!s}:{req.ver!s}'.format(req=req)
             )
 
-        raise raise_from(  # NOTE: Leading "raise" is a hack for mypy bug #9717
-            AnsibleError('\n'.join(error_msg_lines)),
-            dep_exc,
-        )
+        raise AnsibleError('\n'.join(error_msg_lines)) from dep_exc
     except ValueError as exc:
         raise AnsibleError(to_native(exc)) from exc
