@@ -1,9 +1,6 @@
-#!/usr/bin/env python
 """Sanity test using rstcheck and sphinx."""
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-import os
 import re
 import subprocess
 import sys
@@ -20,7 +17,7 @@ def main():
 
     cmd = [
         sys.executable,
-        os.path.join(os.path.dirname(__file__), 'rstcheck-cli.py'),
+        '-c', 'import rstcheck; rstcheck.main();',
         '--report', 'warning',
         '--ignore-substitutions', ','.join(ignore_substitutions),
     ] + paths
