@@ -17,7 +17,7 @@ import tarfile
 import yaml
 
 from io import BytesIO, StringIO
-from units.compat.mock import MagicMock
+from unittest.mock import MagicMock, patch
 
 import ansible.module_utils.six.moves.urllib.error as urllib_error
 
@@ -27,6 +27,7 @@ from ansible.errors import AnsibleError
 from ansible.galaxy import collection, api, dependency_resolution
 from ansible.galaxy.dependency_resolution.dataclasses import Candidate, Requirement
 from ansible.module_utils._text import to_bytes, to_native, to_text
+from ansible.module_utils.common.process import get_bin_path
 from ansible.utils import context_objects as co
 from ansible.utils.display import Display
 
@@ -141,16 +142,16 @@ def collection_artifact(request, tmp_path_factory):
 
     call_galaxy_cli(['init', '%s.%s' % (namespace, collection), '-c', '--init-path', test_dir,
                      '--collection-skeleton', skeleton_path])
-    dependencies = getattr(request, 'param', None)
-    if dependencies:
-        galaxy_yml = os.path.join(collection_path, 'galaxy.yml')
-        with open(galaxy_yml, 'rb+') as galaxy_obj:
-            existing_yaml = yaml.safe_load(galaxy_obj)
-            existing_yaml['dependencies'] = dependencies
+    dependencies = getattr(request, 'param', {})
 
-            galaxy_obj.seek(0)
-            galaxy_obj.write(to_bytes(yaml.safe_dump(existing_yaml)))
-            galaxy_obj.truncate()
+    galaxy_yml = os.path.join(collection_path, 'galaxy.yml')
+    with open(galaxy_yml, 'rb+') as galaxy_obj:
+        existing_yaml = yaml.safe_load(galaxy_obj)
+        existing_yaml['dependencies'] = dependencies
+
+        galaxy_obj.seek(0)
+        galaxy_obj.write(to_bytes(yaml.safe_dump(existing_yaml)))
+        galaxy_obj.truncate()
 
     # Create a file with +x in the collection so we can test the permissions
     execute_path = os.path.join(collection_path, 'runme.sh')
@@ -168,9 +169,27 @@ def collection_artifact(request, tmp_path_factory):
 def galaxy_server():
     context.CLIARGS._store = {'ignore_certs': False}
     galaxy_api = api.GalaxyAPI(None, 'test_server', 'https://galaxy.ansible.com')
+    galaxy_api.get_collection_signatures = MagicMock(return_value=[])
     return galaxy_api
 
 
+def test_concrete_artifact_manager_scm_no_executable(monkeypatch):
+    url = 'https://github.com/org/repo'
+    version = 'commitish'
+    mock_subprocess_check_call = MagicMock()
+    monkeypatch.setattr(collection.concrete_artifact_manager.subprocess, 'check_call', mock_subprocess_check_call)
+    mock_mkdtemp = MagicMock(return_value='')
+    monkeypatch.setattr(collection.concrete_artifact_manager, 'mkdtemp', mock_mkdtemp)
+    mock_get_bin_path = MagicMock(side_effect=[ValueError('Failed to find required executable')])
+    monkeypatch.setattr(collection.concrete_artifact_manager, 'get_bin_path', mock_get_bin_path)
+
+    error = re.escape(
+        "Could not find git executable to extract the collection from the Git repository `https://github.com/org/repo`"
+    )
+    with pytest.raises(AnsibleError, match=error):
+        collection.concrete_artifact_manager._extract_collection_from_git(url, version, b'path')
+
+
 @pytest.mark.parametrize(
     'url,version,trailing_slash',
     [
@@ -193,10 +212,12 @@ def test_concrete_artifact_manager_scm_cmd(url, version, trailing_slash, monkeyp
     repo = 'https://github.com/org/repo'
     if trailing_slash:
         repo += '/'
-    clone_cmd = ('git', 'clone', repo, '')
+
+    git_executable = get_bin_path('git')
+    clone_cmd = (git_executable, 'clone', repo, '')
 
     assert mock_subprocess_check_call.call_args_list[0].args[0] == clone_cmd
-    assert mock_subprocess_check_call.call_args_list[1].args[0] == ('git', 'checkout', 'commitish')
+    assert mock_subprocess_check_call.call_args_list[1].args[0] == (git_executable, 'checkout', 'commitish')
 
 
 @pytest.mark.parametrize(
@@ -222,10 +243,11 @@ def test_concrete_artifact_manager_scm_cmd_shallow(url, version, trailing_slash,
     repo = 'https://github.com/org/repo'
     if trailing_slash:
         repo += '/'
-    shallow_clone_cmd = ('git', 'clone', '--depth=1', repo, '')
+    git_executable = get_bin_path('git')
+    shallow_clone_cmd = (git_executable, 'clone', '--depth=1', repo, '')
 
     assert mock_subprocess_check_call.call_args_list[0].args[0] == shallow_clone_cmd
-    assert mock_subprocess_check_call.call_args_list[1].args[0] == ('git', 'checkout', 'HEAD')
+    assert mock_subprocess_check_call.call_args_list[1].args[0] == (git_executable, 'checkout', 'HEAD')
 
 
 def test_build_requirement_from_path(collection_artifact):
@@ -449,7 +471,9 @@ def test_build_requirement_from_name(galaxy_server, monkeypatch, tmp_path_factor
     requirements = cli._require_one_of_collections_requirements(
         collections, requirements_file, artifacts_manager=concrete_artifact_cm
     )['collections']
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False, False, False
+    )['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -466,7 +490,7 @@ def test_build_requirement_from_name_with_prerelease(galaxy_server, monkeypatch,
     monkeypatch.setattr(galaxy_server, 'get_collection_versions', mock_get_versions)
 
     mock_get_info = MagicMock()
-    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.1', None, None, {})
+    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.1', None, None, {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     test_dir = to_bytes(tmp_path_factory.mktemp('test-ÅÑŚÌβŁÈ Collections Input'))
@@ -476,7 +500,9 @@ def test_build_requirement_from_name_with_prerelease(galaxy_server, monkeypatch,
     requirements = cli._require_one_of_collections_requirements(
         ['namespace.collection'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False, False, False
+    )['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -494,7 +520,7 @@ def test_build_requirment_from_name_with_prerelease_explicit(galaxy_server, monk
 
     mock_get_info = MagicMock()
     mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.1-beta.1', None, None,
-                                                               {})
+                                                               {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     test_dir = to_bytes(tmp_path_factory.mktemp('test-ÅÑŚÌβŁÈ Collections Input'))
@@ -504,7 +530,9 @@ def test_build_requirment_from_name_with_prerelease_explicit(galaxy_server, monk
     requirements = cli._require_one_of_collections_requirements(
         ['namespace.collection:2.0.1-beta.1'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, True, False, False, False, False
+    )['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -521,7 +549,7 @@ def test_build_requirement_from_name_second_server(galaxy_server, monkeypatch, t
     monkeypatch.setattr(galaxy_server, 'get_collection_versions', mock_get_versions)
 
     mock_get_info = MagicMock()
-    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '1.0.3', None, None, {})
+    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '1.0.3', None, None, {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     broken_server = copy.copy(galaxy_server)
@@ -538,7 +566,7 @@ def test_build_requirement_from_name_second_server(galaxy_server, monkeypatch, t
         ['namespace.collection:>1.0.1'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
     actual = collection._resolve_depenency_map(
-        requirements, [broken_server, galaxy_server], concrete_artifact_cm, None, True, False, False
+        requirements, [broken_server, galaxy_server], concrete_artifact_cm, None, True, False, False, False, False
     )['namespace.collection']
 
     assert actual.namespace == u'namespace'
@@ -569,7 +597,7 @@ def test_build_requirement_from_name_missing(galaxy_server, monkeypatch, tmp_pat
 
     expected = "Failed to resolve the requested dependencies map. Could not satisfy the following requirements:\n* namespace.collection:* (direct request)"
     with pytest.raises(AnsibleError, match=re.escape(expected)):
-        collection._resolve_depenency_map(requirements, [galaxy_server, galaxy_server], concrete_artifact_cm, None, False, True, False)
+        collection._resolve_depenency_map(requirements, [galaxy_server, galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)
 
 
 def test_build_requirement_from_name_401_unauthorized(galaxy_server, monkeypatch, tmp_path_factory):
@@ -589,7 +617,7 @@ def test_build_requirement_from_name_401_unauthorized(galaxy_server, monkeypatch
 
     expected = "error (HTTP Code: 401, Message: msg)"
     with pytest.raises(api.GalaxyError, match=re.escape(expected)):
-        collection._resolve_depenency_map(requirements, [galaxy_server, galaxy_server], concrete_artifact_cm, None, False, False, False)
+        collection._resolve_depenency_map(requirements, [galaxy_server, galaxy_server], concrete_artifact_cm, None, False, False, False, False, False)
 
 
 def test_build_requirement_from_name_single_version(galaxy_server, monkeypatch, tmp_path_factory):
@@ -608,7 +636,7 @@ def test_build_requirement_from_name_single_version(galaxy_server, monkeypatch,
 
     mock_get_info = MagicMock()
     mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.0', None, None,
-                                                               {})
+                                                               {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     cli = GalaxyCLI(args=['ansible-galaxy', 'collection', 'install', 'namespace.collection:==2.0.0'])
@@ -616,7 +644,8 @@ def test_build_requirement_from_name_single_version(galaxy_server, monkeypatch,
         ['namespace.collection:==2.0.0'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
 
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -644,7 +673,7 @@ def test_build_requirement_from_name_multiple_versions_one_match(galaxy_server,
 
     mock_get_info = MagicMock()
     mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.1', None, None,
-                                                               {})
+                                                               {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     cli = GalaxyCLI(args=['ansible-galaxy', 'collection', 'install', 'namespace.collection:>=2.0.1,<2.0.2'])
@@ -652,7 +681,8 @@ def test_build_requirement_from_name_multiple_versions_one_match(galaxy_server,
         ['namespace.collection:>=2.0.1,<2.0.2'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
 
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -678,7 +708,7 @@ def test_build_requirement_from_name_multiple_version_results(galaxy_server, mon
     monkeypatch.setattr(dependency_resolution.providers.CollectionDependencyProvider, 'find_matches', mock_find_matches)
 
     mock_get_info = MagicMock()
-    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.5', None, None, {})
+    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.5', None, None, {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     mock_get_versions = MagicMock()
@@ -693,7 +723,8 @@ def test_build_requirement_from_name_multiple_version_results(galaxy_server, mon
         ['namespace.collection:!=2.0.2'], None, artifacts_manager=concrete_artifact_cm
     )['collections']
 
-    actual = collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False)['namespace.collection']
+    actual = collection._resolve_depenency_map(
+        requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)['namespace.collection']
 
     assert actual.namespace == u'namespace'
     assert actual.name == u'collection'
@@ -712,7 +743,7 @@ def test_candidate_with_conflict(monkeypatch, tmp_path_factory, galaxy_server):
     concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(test_dir, validate_certs=False)
 
     mock_get_info = MagicMock()
-    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.5', None, None, {})
+    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '2.0.5', None, None, {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     mock_get_versions = MagicMock()
@@ -727,7 +758,7 @@ def test_candidate_with_conflict(monkeypatch, tmp_path_factory, galaxy_server):
     expected = "Failed to resolve the requested dependencies map. Could not satisfy the following requirements:\n"
     expected += "* namespace.collection:!=2.0.5 (direct request)"
     with pytest.raises(AnsibleError, match=re.escape(expected)):
-        collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False)
+        collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)
 
 
 def test_dep_candidate_with_conflict(monkeypatch, tmp_path_factory, galaxy_server):
@@ -735,8 +766,8 @@ def test_dep_candidate_with_conflict(monkeypatch, tmp_path_factory, galaxy_serve
     concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(test_dir, validate_certs=False)
 
     mock_get_info_return = [
-        api.CollectionVersionMetadata('parent', 'collection', '2.0.5', None, None, {'namespace.collection': '!=1.0.0'}),
-        api.CollectionVersionMetadata('namespace', 'collection', '1.0.0', None, None, {}),
+        api.CollectionVersionMetadata('parent', 'collection', '2.0.5', None, None, {'namespace.collection': '!=1.0.0'}, None, None),
+        api.CollectionVersionMetadata('namespace', 'collection', '1.0.0', None, None, {}, None, None),
     ]
     mock_get_info = MagicMock(side_effect=mock_get_info_return)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
@@ -752,12 +783,12 @@ def test_dep_candidate_with_conflict(monkeypatch, tmp_path_factory, galaxy_serve
     expected = "Failed to resolve the requested dependencies map. Could not satisfy the following requirements:\n"
     expected += "* namespace.collection:!=1.0.0 (dependency of parent.collection:2.0.5)"
     with pytest.raises(AnsibleError, match=re.escape(expected)):
-        collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False)
+        collection._resolve_depenency_map(requirements, [galaxy_server], concrete_artifact_cm, None, False, True, False, False, False)
 
 
 def test_install_installed_collection(monkeypatch, tmp_path_factory, galaxy_server):
 
-    mock_installed_collections = MagicMock(return_value=[Candidate('namespace.collection', '1.2.3', None, 'dir')])
+    mock_installed_collections = MagicMock(return_value=[Candidate('namespace.collection', '1.2.3', None, 'dir', None)])
 
     monkeypatch.setattr(collection, 'find_existing_collections', mock_installed_collections)
 
@@ -768,7 +799,7 @@ def test_install_installed_collection(monkeypatch, tmp_path_factory, galaxy_serv
     monkeypatch.setattr(Display, 'display', mock_display)
 
     mock_get_info = MagicMock()
-    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '1.2.3', None, None, {})
+    mock_get_info.return_value = api.CollectionVersionMetadata('namespace', 'collection', '1.2.3', None, None, {}, None, None)
     monkeypatch.setattr(galaxy_server, 'get_collection_version_metadata', mock_get_info)
 
     mock_get_versions = MagicMock(return_value=['1.2.3', '1.3.0'])
@@ -795,7 +826,7 @@ def test_install_collection(collection_artifact, monkeypatch):
     collection_path = os.path.join(output_path, b'ansible_namespace', b'collection')
     os.makedirs(os.path.join(collection_path, b'delete_me'))  # Create a folder to verify the install cleans out the dir
 
-    candidate = Candidate('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file')
+    candidate = Candidate('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file', None)
     collection.install(candidate, to_text(output_path), concrete_artifact_cm)
 
     # Ensure the temp directory is empty, nothing is left behind
@@ -834,7 +865,7 @@ def test_install_collection_with_download(galaxy_server, collection_artifact, mo
     mock_download.return_value = collection_tar
     monkeypatch.setattr(concrete_artifact_cm, 'get_galaxy_artifact_path', mock_download)
 
-    req = Requirement('ansible_namespace.collection', '0.1.0', 'https://downloadme.com', 'galaxy')
+    req = Candidate('ansible_namespace.collection', '0.1.0', 'https://downloadme.com', 'galaxy', None)
     collection.install(req, to_text(collections_dir), concrete_artifact_cm)
 
     actual_files = os.listdir(collection_path)
@@ -862,8 +893,8 @@ def test_install_collections_from_tar(collection_artifact, monkeypatch):
 
     concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(temp_path, validate_certs=False)
 
-    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file')]
-    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm)
+    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file', None)]
+    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm, True, False)
 
     assert os.path.isdir(collection_path)
 
@@ -887,57 +918,6 @@ def test_install_collections_from_tar(collection_artifact, monkeypatch):
     assert display_msgs[2] == "Installing 'ansible_namespace.collection:0.1.0' to '%s'" % to_text(collection_path)
 
 
-def test_install_collections_existing_without_force(collection_artifact, monkeypatch):
-    collection_path, collection_tar = collection_artifact
-    temp_path = os.path.split(collection_tar)[0]
-
-    mock_display = MagicMock()
-    monkeypatch.setattr(Display, 'display', mock_display)
-
-    concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(temp_path, validate_certs=False)
-
-    assert os.path.isdir(collection_path)
-
-    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file')]
-    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm)
-
-    assert os.path.isdir(collection_path)
-
-    actual_files = os.listdir(collection_path)
-    actual_files.sort()
-    assert actual_files == [b'README.md', b'docs', b'galaxy.yml', b'playbooks', b'plugins', b'roles', b'runme.sh']
-
-    # Filter out the progress cursor display calls.
-    display_msgs = [m[1][0] for m in mock_display.mock_calls if 'newline' not in m[2] and len(m[1]) == 1]
-    assert len(display_msgs) == 1
-
-    assert display_msgs[0] == 'Nothing to do. All requested collections are already installed. If you want to reinstall them, consider using `--force`.'
-
-    for msg in display_msgs:
-        assert 'WARNING' not in msg
-
-
-def test_install_missing_metadata_warning(collection_artifact, monkeypatch):
-    collection_path, collection_tar = collection_artifact
-    temp_path = os.path.split(collection_tar)[0]
-
-    mock_display = MagicMock()
-    monkeypatch.setattr(Display, 'display', mock_display)
-
-    for file in [b'MANIFEST.json', b'galaxy.yml']:
-        b_path = os.path.join(collection_path, file)
-        if os.path.isfile(b_path):
-            os.unlink(b_path)
-
-    concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(temp_path, validate_certs=False)
-    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file')]
-    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm)
-
-    display_msgs = [m[1][0] for m in mock_display.mock_calls if 'newline' not in m[2] and len(m[1]) == 1]
-
-    assert 'WARNING' in display_msgs[0]
-
-
 # Makes sure we don't get stuck in some recursive loop
 @pytest.mark.parametrize('collection_artifact', [
     {'ansible_namespace.collection': '>=0.0.1'},
@@ -951,8 +931,8 @@ def test_install_collection_with_circular_dependency(collection_artifact, monkey
     monkeypatch.setattr(Display, 'display', mock_display)
 
     concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(temp_path, validate_certs=False)
-    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file')]
-    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm)
+    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file', None)]
+    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm, True, False)
 
     assert os.path.isdir(collection_path)
 
@@ -967,6 +947,7 @@ def test_install_collection_with_circular_dependency(collection_artifact, monkey
     assert actual_manifest['collection_info']['namespace'] == 'ansible_namespace'
     assert actual_manifest['collection_info']['name'] == 'collection'
     assert actual_manifest['collection_info']['version'] == '0.1.0'
+    assert actual_manifest['collection_info']['dependencies'] == {'ansible_namespace.collection': '>=0.0.1'}
 
     # Filter out the progress cursor display calls.
     display_msgs = [m[1][0] for m in mock_display.mock_calls if 'newline' not in m[2] and len(m[1]) == 1]
@@ -975,3 +956,74 @@ def test_install_collection_with_circular_dependency(collection_artifact, monkey
     assert display_msgs[1] == "Starting collection install process"
     assert display_msgs[2] == "Installing 'ansible_namespace.collection:0.1.0' to '%s'" % to_text(collection_path)
     assert display_msgs[3] == "ansible_namespace.collection:0.1.0 was installed successfully"
+
+
+@pytest.mark.parametrize('collection_artifact', [
+    None,
+    {},
+], indirect=True)
+def test_install_collection_with_no_dependency(collection_artifact, monkeypatch):
+    collection_path, collection_tar = collection_artifact
+    temp_path = os.path.split(collection_tar)[0]
+    shutil.rmtree(collection_path)
+
+    concrete_artifact_cm = collection.concrete_artifact_manager.ConcreteArtifactsManager(temp_path, validate_certs=False)
+    requirements = [Requirement('ansible_namespace.collection', '0.1.0', to_text(collection_tar), 'file', None)]
+    collection.install_collections(requirements, to_text(temp_path), [], False, False, False, False, False, False, concrete_artifact_cm, True, False)
+
+    assert os.path.isdir(collection_path)
+
+    with open(os.path.join(collection_path, b'MANIFEST.json'), 'rb') as manifest_obj:
+        actual_manifest = json.loads(to_text(manifest_obj.read()))
+
+    assert not actual_manifest['collection_info']['dependencies']
+    assert actual_manifest['collection_info']['namespace'] == 'ansible_namespace'
+    assert actual_manifest['collection_info']['name'] == 'collection'
+    assert actual_manifest['collection_info']['version'] == '0.1.0'
+
+
+@pytest.mark.parametrize(
+    "signatures,required_successful_count,ignore_errors,expected_success",
+    [
+        ([], 'all', [], True),
+        (["good_signature"], 'all', [], True),
+        (["good_signature", collection.gpg.GpgBadArmor(status='failed')], 'all', [], False),
+        ([collection.gpg.GpgBadArmor(status='failed')], 'all', [], False),
+        # This is expected to succeed because ignored does not increment failed signatures.
+        # "all" signatures is not a specific number, so all == no (non-ignored) signatures in this case.
+        ([collection.gpg.GpgBadArmor(status='failed')], 'all', ["BADARMOR"], True),
+        ([collection.gpg.GpgBadArmor(status='failed'), "good_signature"], 'all', ["BADARMOR"], True),
+        ([], '+all', [], False),
+        ([collection.gpg.GpgBadArmor(status='failed')], '+all', ["BADARMOR"], False),
+        ([], '1', [], True),
+        ([], '+1', [], False),
+        (["good_signature"], '2', [], False),
+        (["good_signature", collection.gpg.GpgBadArmor(status='failed')], '2', [], False),
+        # This is expected to fail because ignored does not increment successful signatures.
+        # 2 signatures are required, but only 1 is successful.
+        (["good_signature", collection.gpg.GpgBadArmor(status='failed')], '2', ["BADARMOR"], False),
+        (["good_signature", "good_signature"], '2', [], True),
+    ]
+)
+def test_verify_file_signatures(signatures, required_successful_count, ignore_errors, expected_success):
+    # type: (List[bool], int, bool, bool) -> None
+
+    def gpg_error_generator(results):
+        for result in results:
+            if isinstance(result, collection.gpg.GpgBaseError):
+                yield result
+
+    fqcn = 'ns.coll'
+    manifest_file = 'MANIFEST.json'
+    keyring = '~/.ansible/pubring.kbx'
+
+    with patch.object(collection, 'run_gpg_verify', MagicMock(return_value=("somestdout", 0,))):
+        with patch.object(collection, 'parse_gpg_errors', MagicMock(return_value=gpg_error_generator(signatures))):
+            assert collection.verify_file_signatures(
+                fqcn,
+                manifest_file,
+                signatures,
+                keyring,
+                required_successful_count,
+                ignore_errors
+            ) == expected_success
